pub struct ActionPin {
pub pinned: String,
pub action: String,
pub tag: String,
pub commit_sha: String,
pub url: Option<String>,
}Expand description
A pinned GitHub Action: the ready-to-paste reference plus its parts.
Fields
pinned: Stringaction: Stringtag: Stringcommit_sha: Stringurl: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ActionPin
impl<'de> Deserialize<'de> for ActionPin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActionPin
impl JsonSchema for ActionPin
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActionPin
impl RefUnwindSafe for ActionPin
impl Send for ActionPin
impl Sync for ActionPin
impl Unpin for ActionPin
impl UnsafeUnpin for ActionPin
impl UnwindSafe for ActionPin