pub struct LatestVersion {
pub found: bool,
pub name: String,
pub registry: String,
pub version: Option<VersionInfo>,
}Expand description
Result of a latest-stable-version lookup: the version when one exists, or a
not-found marker. found: true with version: None means the package
exists but publishes no stable (non-prerelease) release.
Fields
found: boolname: Stringregistry: Stringversion: Option<VersionInfo>Trait Implementations
Sourceimpl Clone for LatestVersion
impl Clone for LatestVersion
Sourcefn clone(&self) -> LatestVersion
fn clone(&self) -> LatestVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatestVersion
impl Debug for LatestVersion
Sourceimpl<'de> Deserialize<'de> for LatestVersion
impl<'de> Deserialize<'de> for LatestVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LatestVersion
impl JsonSchema for LatestVersion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LatestVersion
impl RefUnwindSafe for LatestVersion
impl Send for LatestVersion
impl Sync for LatestVersion
impl Unpin for LatestVersion
impl UnsafeUnpin for LatestVersion
impl UnwindSafe for LatestVersion