pub struct PackageInfo {
pub name: String,
pub registry: String,
pub latest_version: Option<String>,
pub description: Option<String>,
pub license: Option<String>,
pub homepage: Option<String>,
pub repository: Option<String>,
pub authors: Vec<String>,
pub updated_at: Option<DateTime<Utc>>,
pub keywords: Vec<String>,
pub classifiers: Vec<String>,
pub requires_python: Option<String>,
}Expand description
Package metadata from a registry.
Fields
name: Stringregistry: Stringlatest_version: Option<String>description: Option<String>license: Option<String>homepage: Option<String>repository: Option<String>updated_at: Option<DateTime<Utc>>keywords: Vec<String>classifiers: Vec<String>requires_python: Option<String>Trait Implementations
Sourceimpl Clone for PackageInfo
impl Clone for PackageInfo
Sourcefn clone(&self) -> PackageInfo
fn clone(&self) -> PackageInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageInfo
impl Debug for PackageInfo
Sourceimpl<'de> Deserialize<'de> for PackageInfo
impl<'de> Deserialize<'de> for PackageInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PackageInfo
impl JsonSchema for PackageInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PackageInfo
impl RefUnwindSafe for PackageInfo
impl Send for PackageInfo
impl Sync for PackageInfo
impl Unpin for PackageInfo
impl UnsafeUnpin for PackageInfo
impl UnwindSafe for PackageInfo