pub struct ReleaseAsset {
pub name: String,
pub size: u64,
pub download_url: String,
pub download_count: u64,
pub content_type: String,
}Expand description
A downloadable asset attached to a release.
Fields
name: Stringsize: u64download_url: Stringdownload_count: u64content_type: StringTrait Implementations
Sourceimpl Clone for ReleaseAsset
impl Clone for ReleaseAsset
Sourcefn clone(&self) -> ReleaseAsset
fn clone(&self) -> ReleaseAsset
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReleaseAsset
impl Debug for ReleaseAsset
Sourceimpl<'de> Deserialize<'de> for ReleaseAsset
impl<'de> Deserialize<'de> for ReleaseAsset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReleaseAsset
impl JsonSchema for ReleaseAsset
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReleaseAsset
impl RefUnwindSafe for ReleaseAsset
impl Send for ReleaseAsset
impl Sync for ReleaseAsset
impl Unpin for ReleaseAsset
impl UnsafeUnpin for ReleaseAsset
impl UnwindSafe for ReleaseAsset