pub struct ReleaseInfo {
pub tag: String,
pub name: Option<String>,
pub published_at: Option<DateTime<Utc>>,
pub prerelease: bool,
pub draft: bool,
pub html_url: String,
pub assets: Vec<ReleaseAsset>,
}Expand description
A release from a forge repository.
Fields
tag: Stringname: Option<String>published_at: Option<DateTime<Utc>>prerelease: booldraft: boolhtml_url: Stringassets: Vec<ReleaseAsset>Trait Implementations
Sourceimpl Clone for ReleaseInfo
impl Clone for ReleaseInfo
Sourcefn clone(&self) -> ReleaseInfo
fn clone(&self) -> ReleaseInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReleaseInfo
impl Debug for ReleaseInfo
Sourceimpl<'de> Deserialize<'de> for ReleaseInfo
impl<'de> Deserialize<'de> for ReleaseInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReleaseInfo
impl JsonSchema for ReleaseInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReleaseInfo
impl RefUnwindSafe for ReleaseInfo
impl Send for ReleaseInfo
impl Sync for ReleaseInfo
impl Unpin for ReleaseInfo
impl UnsafeUnpin for ReleaseInfo
impl UnwindSafe for ReleaseInfo