pub struct RepositorySearchResult {
pub forge: String,
pub full_name: String,
pub owner: String,
pub name: String,
pub description: Option<String>,
pub stars: u64,
pub language: Option<String>,
pub topics: Vec<String>,
pub url: String,
pub updated_at: Option<DateTime<Utc>>,
}Expand description
A repository/project search hit from a code forge.
Fields
forge: Stringfull_name: Stringowner: Stringname: Stringdescription: Option<String>stars: u64language: Option<String>topics: Vec<String>url: Stringupdated_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for RepositorySearchResult
impl Clone for RepositorySearchResult
Sourcefn clone(&self) -> RepositorySearchResult
fn clone(&self) -> RepositorySearchResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepositorySearchResult
impl Debug for RepositorySearchResult
Sourceimpl<'de> Deserialize<'de> for RepositorySearchResult
impl<'de> Deserialize<'de> for RepositorySearchResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RepositorySearchResult
impl JsonSchema for RepositorySearchResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepositorySearchResult
impl RefUnwindSafe for RepositorySearchResult
impl Send for RepositorySearchResult
impl Sync for RepositorySearchResult
impl Unpin for RepositorySearchResult
impl UnsafeUnpin for RepositorySearchResult
impl UnwindSafe for RepositorySearchResult