pub struct RuntimeInfo {
pub id: String,
pub name: String,
pub latest_stable: String,
pub latest_cycle: String,
pub changelog_url: Option<String>,
pub versions: Vec<RuntimeVersion>,
}Expand description
Runtime lifecycle info from endoflife.date.
Fields
id: Stringname: Stringlatest_stable: Stringlatest_cycle: Stringchangelog_url: Option<String>versions: Vec<RuntimeVersion>Trait Implementations
Sourceimpl Clone for RuntimeInfo
impl Clone for RuntimeInfo
Sourcefn clone(&self) -> RuntimeInfo
fn clone(&self) -> RuntimeInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeInfo
impl Debug for RuntimeInfo
Sourceimpl<'de> Deserialize<'de> for RuntimeInfo
impl<'de> Deserialize<'de> for RuntimeInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RuntimeInfo
impl JsonSchema for RuntimeInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuntimeInfo
impl RefUnwindSafe for RuntimeInfo
impl Send for RuntimeInfo
impl Sync for RuntimeInfo
impl Unpin for RuntimeInfo
impl UnsafeUnpin for RuntimeInfo
impl UnwindSafe for RuntimeInfo