pub struct RuntimeVersion {
pub cycle: String,
pub latest: String,
pub release_date: Option<NaiveDate>,
pub latest_release_date: Option<NaiveDate>,
pub eol: EolStatus,
pub lts: bool,
pub support: Option<EolStatus>,
}Expand description
A runtime version cycle with EOL status.
Fields
cycle: Stringlatest: Stringrelease_date: Option<NaiveDate>latest_release_date: Option<NaiveDate>eol: EolStatuslts: boolsupport: Option<EolStatus>Trait Implementations
Sourceimpl Clone for RuntimeVersion
impl Clone for RuntimeVersion
Sourcefn clone(&self) -> RuntimeVersion
fn clone(&self) -> RuntimeVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeVersion
impl Debug for RuntimeVersion
Sourceimpl<'de> Deserialize<'de> for RuntimeVersion
impl<'de> Deserialize<'de> for RuntimeVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RuntimeVersion
impl JsonSchema for RuntimeVersion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuntimeVersion
impl RefUnwindSafe for RuntimeVersion
impl Send for RuntimeVersion
impl Sync for RuntimeVersion
impl Unpin for RuntimeVersion
impl UnsafeUnpin for RuntimeVersion
impl UnwindSafe for RuntimeVersion