pub struct VersionList {
pub found: bool,
pub name: String,
pub registry: String,
pub latest: Option<String>,
pub versions: Vec<VersionInfo>,
}Expand description
Result of a version listing: the versions when the package exists, or a not-found marker meaning the name is free on this registry.
Fields
found: boolname: Stringregistry: Stringlatest: Option<String>versions: Vec<VersionInfo>Trait Implementations
Sourceimpl Clone for VersionList
impl Clone for VersionList
Sourcefn clone(&self) -> VersionList
fn clone(&self) -> VersionList
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VersionList
impl Debug for VersionList
Sourceimpl<'de> Deserialize<'de> for VersionList
impl<'de> Deserialize<'de> for VersionList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VersionList
impl JsonSchema for VersionList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VersionList
impl RefUnwindSafe for VersionList
impl Send for VersionList
impl Sync for VersionList
impl Unpin for VersionList
impl UnsafeUnpin for VersionList
impl UnwindSafe for VersionList